==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/homekit/HMAccessorySetupManager.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.homekit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 15.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("HomeKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/HMAccessorySetupManager/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class HMAccessorySetupManagerPtr extends Ptr<HMAccessorySetupManager, HMAccessorySetupManagerPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(HMAccessorySetupManager.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public HMAccessorySetupManager() {}
    protected HMAccessorySetupManager(Handle h, long handle) { super(h, handle); }
    protected HMAccessorySetupManager(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "addAndSetUpAccessoriesForTopology:completionHandler:")
    public native void addAndSetUpAccessories(HMMatterTopology topology, @Block VoidBlock1<NSError> completion);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/homekit/HMAccessorySetupManager.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.homekit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 15.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("HomeKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/HMAccessorySetupManager/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class HMAccessorySetupManagerPtr extends Ptr<HMAccessorySetupManager, HMAccessorySetupManagerPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(HMAccessorySetupManager.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public HMAccessorySetupManager() {}
    protected HMAccessorySetupManager(Handle h, long handle) { super(h, handle); }
    protected HMAccessorySetupManager(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    /**
     * @since Available in iOS 15.4 and later.
     */
    @Method(selector = "performAccessorySetupUsingRequest:completionHandler:")
    public native void performAccessorySetupUsingRequest(HMAccessorySetupRequest request, @Block VoidBlock2<HMAccessorySetupResult, NSError> completion);
    /**
     * @since Available in iOS 15.4 and later.
     */
    @Method(selector = "performMatterEcosystemAccessorySetupUsingRequest:topology:completionHandler:")
    public native void performMatterEcosystemAccessorySetupUsingRequest(HMAccessorySetupRequest request, HMMatterTopology topology, @Block VoidBlock1<NSError> completion);
    /**
     * @since Available in iOS 15.0 and later.
     * @deprecated Deprecated in iOS 15.4. Use -[HMAccessorySetupManager performAccessorySetupUsingRequest:topology:completionHandler:] instead
     */
    @Deprecated
    @Method(selector = "addAndSetUpAccessoriesForTopology:completionHandler:")
    public native void addAndSetUpAccessories(HMMatterTopology topology, @Block VoidBlock1<NSError> completion);
    /*</methods>*/
}
